==> vue-condition-watcher-1.3.0.tgz: package/esm/core/utils/common.js <==
const fromEntries = (xs) => Object.fromEntries ? Object.fromEntries(xs) : xs.reduce((acc, [key, value]) => ({ ...acc, [key]: value }), {});
export function createParams(conditions, defaultParams) {
    const _conditions = {
        ...conditions,
        ...defaultParams,
    };
    Object.entries(_conditions).forEach(([key, value]) => {
        if (Array.isArray(value)) {
            _conditions[key] = value.join(',');
        }
    });
    return _conditions;
}
export function filterNoneValueObject(object) {
    return fromEntries(Object.entries(object).filter((item) => {
        const value = item[1];
        return typeof value !== 'undefined' && value !== null && value !== '' && value.length !== 0;
    }));
}
export function stringifyQuery(params, ignoreKeys) {
    const esc = encodeURIComponent;
    return Object.entries(params)
        .filter(([key, value]) => typeof value !== 'undefined' &&
        value !== null &&
        value !== '' &&
        (Array.isArray(value) ? value.length !== 0 : true) &&
        (ignoreKeys && ignoreKeys.length ? !ignoreKeys.includes(key) : true))
        .map(([key, value]) => {
        return esc(key) + (value != null ? '=' + esc(value) : '');
    })
        .join('&');
}
export function syncQuery2Conditions(conditions, query) {
    const conditions2Object = { ...conditions };
    const noQuery = Object.keys(query).length === 0;
    Object.keys(conditions2Object).forEach((key) => {
        if (key in query || noQuery) {
            if (conditions2Object[key] instanceof Date) {
                conditions[key] = noQuery ? null : new Date(query[key]);
                return;
            }
            conditions[key] = Array.isArray(conditions2Object[key])
                ? noQuery || !query[key].length
                    ? []
                    : typeof query[key] === 'string'
                        ? query[key].split(',')
                        : query[key]
                : typeof conditions2Object[key] === 'number'
                    ? noQuery
                        ? 0
                        : +query[key]
                    : noQuery
                        ? ''
                        : query[key];
        }
    });
}
export function isEquivalentString(a, b, ignore) {
    return stringifyQuery(a, ignore) === stringifyQuery(b, ignore);
}
export function isEquivalent(x, y) {
    if (x === null || x === undefined || y === null || y === undefined) {
        return x === y;
    }
    if (x.constructor !== y.constructor) {
        return false;
    }
    if (x instanceof Function) {
        return x === y;
    }
    if (x instanceof RegExp) {
        return x === y;
    }
    if (x === y || x.valueOf() === y.valueOf()) {
        return true;
    }
    if (Array.isArray(x) && x.length !== y.length) {
        return false;
    }
    if (x instanceof Date) {
        return false;
    }
    if (!(x instanceof Object)) {
        return false;
    }
    if (!(y instanceof Object)) {
        return false;
    }
    let p = Object.keys(x);
    return (Object.keys(y).every((i) => {
        return p.indexOf(i) !== -1;
    }) &&
        p.every((i) => {
            return isEquivalent(x[i], y[i]);
        }));
}
export function deepClone(obj) {
    if (obj === null)
        return null;
    let clone = Object.assign({}, obj);
    Object.keys(clone).forEach((key) => {
        if (obj[key] instanceof Date) {
            const original = obj[key];
            clone[key] = new Date(original);
            return;
        }
        clone[key] = typeof obj[key] === 'object' ? deepClone(obj[key]) : obj[key];
    });
    return Array.isArray(obj) && obj.length
        ? (clone.length = obj.length) && Array.from(clone)
        : Array.isArray(obj)
            ? Array.from(obj)
            : clone;
}
export function containsProp(obj, ...props) {
    if (!isObject(obj))
        return false;
    return props.some((k) => k in obj);
}
export function isObject(obj) {
    return typeof obj !== 'boolean' && typeof obj === 'object' && !Array.isArray(obj) && obj !== null;
}

==> vue-condition-watcher-1.4.0.tgz: package/esm/core/utils/common.js <==
const fromEntries = (xs) => Object.fromEntries ? Object.fromEntries(xs) : xs.reduce((acc, [key, value]) => ({ ...acc, [key]: value }), {});
export function createParams(conditions, defaultParams) {
    const _conditions = {
        ...conditions,
        ...defaultParams,
    };
    Object.entries(_conditions).forEach(([key, value]) => {
        if (Array.isArray(value)) {
            _conditions[key] = value.join(',');
        }
    });
    return _conditions;
}
export function filterNoneValueObject(object) {
    return fromEntries(Object.entries(object).filter((item) => {
        const value = item[1];
        return typeof value !== 'undefined' && value !== null && value !== '' && value.length !== 0;
    }));
}
export function stringifyQuery(params, ignoreKeys) {
    const esc = encodeURIComponent;
    return Object.entries(params)
        .filter(([key, value]) => typeof value !== 'undefined' &&
        value !== null &&
        value !== '' &&
        (Array.isArray(value) ? value.length !== 0 : true) &&
        (ignoreKeys && ignoreKeys.length ? !ignoreKeys.includes(key) : true))
        .map(([key, value]) => {
        return esc(key) + (value != null ? '=' + esc(value) : '');
    })
        .join('&');
}
export function syncQuery2Conditions(conditions, query) {
    const conditions2Object = { ...conditions };
    const noQuery = Object.keys(query).length === 0;
    Object.keys(conditions2Object).forEach((key) => {
        if (key in query || noQuery) {
            if (conditions2Object[key] instanceof Date) {
                conditions[key] = noQuery ? null : new Date(query[key]);
                return;
            }
            conditions[key] = Array.isArray(conditions2Object[key])
                ? noQuery || !query[key].length
                    ? []
                    : typeof query[key] === 'string'
                        ? query[key].split(',')
                        : query[key]
                : typeof conditions2Object[key] === 'number'
                    ? noQuery
                        ? 0
                        : +query[key]
                    : noQuery
                        ? ''
                        : query[key];
        }
    });
}
export function isEquivalentString(a, b, ignore) {
    return stringifyQuery(a, ignore) === stringifyQuery(b, ignore);
}
export function isEquivalent(x, y) {
    if (x === null || x === undefined || y === null || y === undefined) {
        return x === y;
    }
    if (x.constructor !== y.constructor) {
        return false;
    }
    if (x instanceof Function) {
        return x === y;
    }
    if (x instanceof RegExp) {
        return x === y;
    }
    if (x === y || x.valueOf() === y.valueOf()) {
        return true;
    }
    if (Array.isArray(x) && x.length !== y.length) {
        return false;
    }
    if (x instanceof Date) {
        return false;
    }
    if (!(x instanceof Object)) {
        return false;
    }
    if (!(y instanceof Object)) {
        return false;
    }
    let p = Object.keys(x);
    return (Object.keys(y).every((i) => {
        return p.indexOf(i) !== -1;
    }) &&
        p.every((i) => {
            return isEquivalent(x[i], y[i]);
        }));
}
export function deepClone(obj) {
    if (obj === null)
        return null;
    let clone = Object.assign({}, obj);
    Object.keys(clone).forEach((key) => {
        if (obj[key] instanceof Date) {
            const original = obj[key];
            clone[key] = new Date(original);
            return;
        }
        clone[key] = typeof obj[key] === 'object' ? deepClone(obj[key]) : obj[key];
    });
    return Array.isArray(obj) && obj.length
        ? (clone.length = obj.length) && Array.from(clone)
        : Array.isArray(obj)
            ? Array.from(obj)
            : clone;
}
export function mergeObjects(a, b) {
    return Object.assign({}, a, b);
}
export function sortObject(unordered) {
    return Object.keys(unordered)
        .sort()
        .reduce((obj, key) => {
        obj[key] = unordered[key];
        return obj;
    }, {});
}
